@@ -5,19 +5,23 @@ DEFAULT_MODEL = "SD-1.5"
 DEFAULT_SAMPLER = "k_dpmpp_2m"
 
 DEFAULT_NEGATIVE_PROMPT = (
-    "(weird eyes:1.5), (smudged face:1.8), (blurred face:1.5), (poorly drawn face:1.5), mutation, mutilation, (cloned face:2.0), (strange mouth:1.5), (duplicated face:2.0), "
-    "(Ugly:1.5), (duplication:1.5), duplicates, mutilation, deformed, mutilated, (mutation:1.5), (twisted body:1.5), (disfigured:1.5), (bad anatomy:1.5), "
-    "(poorly drawn hands:1.5), (extra limbs:1.5), (malformed limbs:1.5), (missing arms:1.5), (extra arms:1.5), (missing legs:1.5), (extra legs:1.5), (mutated hands:1.5), "
-    "(extra hands:1.5), (fused fingers:1.5), (missing fingers:1.5), extra fingers, (long neck:1.8), small head, (closed eyes:1.5), rolling eyes, "
-    "grainy, blurred, blurry, (writing:1.5), calligraphy, (text:3.0), (watermark:1.5), bad art, missing fingers, (missing limbs:1.5), "
-    "(out of frame:1.5), (extra fingers:1.5), (mutated hands:1.5), (porn:1.5), (child abuse:1.5), (horrific images:1.5), (dead bodies:1.5), "
-    "(watermark:1.5), child, (lowres:1.5), bad anatomy, bad hands, text, error, (missing fingers:1.5), (extra digit:1.5), (fewer digits:1.6), (cropped:1.5), "
-    "worst quality, (low quality:1.5), normal quality, jpeg artifacts, (signature:1.5), watermark, username, blurry, (bad feet:1.5), (bad lighting:1.3), "
-    "bad coloring, bad perspective, (bad focus:1.5), (bad design:1.3), (bad eyes:1.7), (bad hair:1.7), bad nose, bad mouth, bad ears, bad teeth, bad tongue, bad lips, "
-    "(nude:1.5), (naked:1.5), (paedophile:2.0), (pedo:2.0), (floating limbs: 1.5), (bad art, low detail:1.5), (plain background, grainy, low "
-    "quality, mutated hands and fingers:1.4), (watermark, thin lines:1.2), (deformed, signature:1.2), (blurry, ugly, bad anatomy, extra"
-    "limbs, undersaturated, low resolution:1.5), (disfigured, deformations, out of frame:1.5), (amputee:1.8), (bad proportions:1.5), (extra limb:1.5), (missing"
-    "limbs:1.4), (distortion:1.5), (out of frame:2.0), (poorly drawn face:2.0), (poorly drawn hands:1.5), (text:1.8), malformed, (cropped:1.5)"
+    "weird eyes, smudged face, blurred face, poorly drawn face, mutation, mutilation, cloned face, strange mouth, duplicated face, "
+    "Ugly, duplication, duplicates, mutilation, deformed, mutilated, mutation, twisted body, disfigured, bad anatomy, "
+    "poorly drawn hands, extra limbs, malformed limbs, missing arms, extra arms, missing legs, extra legs, mutated hands, "
+    "extra hands, fused fingers, missing fingers, extra fingers, long neck, small head, closed eyes, rolling eyes, "
+    "grainy, blurred, blurry, writing, calligraphy, text, watermark, bad art, missing fingers, missing limbs, "
+    "out of frame, extra fingers, mutated hands, porn, child abuse, horrific images, dead bodies, "
+    "watermark, child, lowres, bad anatomy, bad hands, text, error, missing fingers, extra digit, fewer digits, cropped, "
+    "worst quality, low quality, normal quality, jpeg artifacts, signature, watermark, username, blurry, bad feet, bad lighting, "
+    "bad coloring, bad perspective, bad focus, bad design, bad eyes, bad hair, bad nose, bad mouth, bad ears, bad teeth, bad tongue, bad lips, "
+    "nude, naked, paedophile, pedo, floating limbs, bad art, low detail, plain background, grainy, low "
+    "quality, mutated hands and fingers, watermark, thin lines, deformed, signature, blurry, ugly, bad anatomy, extra"
+    "limbs, undersaturated, low resolution, disfigured, deformations, out of frame, amputee, bad proportions, extra limb, missing"
+    "limbs, distortion, out of frame, poorly drawn face, poorly drawn hands, text, malformed, cropped, "
+    "clashing colors, pixelated, overexposed, underexposed, unbalanced composition, excessive noise, red-eye, "
+    "distracting background, poor framing, tilted horizon, lack of contrast, over-saturated, lens flare, "
+    "awkward pose, unflattering angle, harsh shadows, flat lighting, lack of focus, over-processed, "
+    "visible artifacts, chromatic aberration, ghosting, moire patterns, banding, halo effect"
 )
 
 SPLITMEM_ENABLED = False
